ScyllaDB University Live | Free Virtual Training Event
Learn more
ScyllaDB Documentation Logo Documentation
  • Deployments
    • Cloud
    • Server
  • Tools
    • ScyllaDB Manager
    • ScyllaDB Monitoring Stack
    • ScyllaDB Operator
  • Drivers
    • CQL Drivers
    • DynamoDB Drivers
    • Supported Driver Versions
  • Resources
    • ScyllaDB University
    • Community Forum
    • Tutorials
Install
Ask AI
ScyllaDB Docs ScyllaDB CPP RS Driver API Documentation CassAuthenticator

Caution

You're viewing documentation for an unstable version of ScyllaDB CPP RS Driver. Switch to the latest stable version.

CassAuthenticator¶

struct CassAuthenticator¶

An authenticator.

Public Functions

void cass_authenticator_address(const CassAuthenticator *auth, CassInet *address)¶

Gets the IP address of the host being authenticated.

Warning: This function is not yet implemented.

Parameters:
  • auth – [in]

  • address – [out]

const char *cass_authenticator_hostname(const CassAuthenticator *auth, size_t *length)¶

Gets the hostname of the host being authenticated.

Warning: This function is not yet implemented.

Parameters:
  • auth – [in]

  • length – [out]

Returns:

A null-terminated string.

const char *cass_authenticator_class_name(const CassAuthenticator *auth, size_t *length)¶

Gets the class name for the server-side IAuthentication implementation.

Warning: This function is not yet implemented.

Parameters:
  • auth – [in]

  • length – [out]

Returns:

A null-terminated string.

void *cass_authenticator_exchange_data(CassAuthenticator *auth)¶

Gets the user data created during the authenticator exchange. This is set using cass_authenticator_set_exchange_data().

Warning: This function is not yet implemented.

See also

cass_authenticator_set_exchange_data()

Parameters:

auth – [in]

Returns:

User specified exchange data previously set by cass_authenticator_set_exchange_data().

void cass_authenticator_set_exchange_data(CassAuthenticator *auth, void *exchange_data)¶

Sets the user data to be used during the authenticator exchange.

Warning: This function is not yet implemented.

See also

cass_authenticator_exchange_data()

Parameters:
  • auth – [in]

  • exchange_data –

char *cass_authenticator_response(CassAuthenticator *auth, size_t size)¶

Gets a response token buffer of the provided size.

Warning: This function is not yet implemented.

Parameters:
  • auth – [in]

  • size – [in]

Returns:

A buffer to copy the response token.

void cass_authenticator_set_response(CassAuthenticator *auth, const char *response, size_t response_size)¶

Sets the response token.

Warning: This function is not yet implemented.

Parameters:
  • auth – [in]

  • response – [in]

  • response_size – [in]

void cass_authenticator_set_error(CassAuthenticator *auth, const char *message)¶

Sets an error for the authenticator exchange.

Warning: This function is not yet implemented.

Parameters:
  • auth – [in]

  • message – [in]

void cass_authenticator_set_error_n(CassAuthenticator *auth, const char *message, size_t message_length)¶

Same as cass_authenticator_set_error(), but with lengths for string parameters.

Warning: This function is not yet implemented.

See also

cass_authenticator_set_error()

Parameters:
  • auth – [in]

  • message – [in]

  • message_length –

Was this page helpful?

PREVIOUS
CassAggregateMeta
NEXT
CassAuthenticatorCallbacks
  • Create an issue
  • Edit this page

On this page

  • CassAuthenticator
    • CassAuthenticator
      • cass_authenticator_address()
      • cass_authenticator_hostname()
      • cass_authenticator_class_name()
      • cass_authenticator_exchange_data()
      • cass_authenticator_set_exchange_data()
      • cass_authenticator_response()
      • cass_authenticator_set_response()
      • cass_authenticator_set_error()
      • cass_authenticator_set_error_n()
ScyllaDB CPP RS Driver
  • master
    • master
    • v1.0.0
  • ScyllaDB CPP RS Driver
  • API Documentation
    • BasicTypes
    • CassConsistency
    • CassError
    • CassValueType
    • CustomAllocator
    • Logging
    • Miscellaneous
    • CassAggregateMeta
    • CassAuthenticator
    • CassAuthenticatorCallbacks
    • CassBatch
    • CassCluster
    • CassCollection
    • CassColumnMeta
    • CassCustomPayload
    • CassDataType
    • CassErrorResult
    • CassExecProfile
    • CassFunctionMeta
    • CassFuture
    • CassIndexMeta
    • CassInet
    • CassIterator
    • CassKeyspaceMeta
    • CassMaterializedViewMeta
    • CassMetrics
    • CassNode
    • CassPrepared
    • CassResult
    • CassRetryPolicy
    • CassRow
    • CassSchemaMeta
    • CassSession
    • CassSpeculativeExecutionMetrics
    • CassSsl
    • CassStatement
    • CassTableMeta
    • CassTimestampGen
    • CassTuple
    • CassUserType
    • CassUuid
    • CassUuidGen
    • CassValue
    • CassVersion
  • Getting Started
  • Architecture Overview
  • Installation
  • Building
  • Testing
  • Using the Driver
    • Batches
    • Binding Parameters
    • Client-side timestamps
    • Consistency
    • Data Types
      • The date and time Types
      • Tuples
      • User-Defined Types (UDTs)
      • UUIDs
    • Futures
    • Handling Results
    • Keyspaces
    • Prepared Statements
    • Schema Metadata
  • Configuration
    • Load balancing
    • Retry policies
    • Speculative Execution
    • Connection
    • Execution Profiles
    • Performance Tips
    • Client Configuration
  • Security
    • Authentication
    • TLS
  • Observability
    • Logging
    • Tracing
    • Metrics
Docs Tutorials University Contact Us About Us
© 2026, ScyllaDB. All rights reserved. | Terms of Service | Privacy Policy | ScyllaDB, and ScyllaDB Cloud, are registered trademarks of ScyllaDB, Inc.
Last updated on 17 Mar 2026.
Powered by Sphinx 9.1.0 & ScyllaDB Theme 1.9.1
Ask AI