ScyllaDB University Live | Free Virtual Training Event
Learn more
ScyllaDB Documentation Logo Documentation
  • Deployments
    • Cloud
    • Server
  • Tools
    • ScyllaDB Manager
    • ScyllaDB Monitoring Stack
    • ScyllaDB Operator
  • Drivers
    • CQL Drivers
    • DynamoDB Drivers
    • Supported Driver Versions
  • Resources
    • ScyllaDB University
    • Community Forum
    • Tutorials
Install
Ask AI
ScyllaDB Docs ScyllaDB CPP RS Driver API Documentation CassIterator

Caution

You're viewing documentation for an unstable version of ScyllaDB CPP RS Driver. Switch to the latest stable version.

CassIterator¶

struct CassIterator¶

An object used to iterate over a group of rows, columns or collection values.

Public Types

enum CassIteratorType¶

Values:

Public Functions

void cass_iterator_free(CassIterator *iterator)¶

Frees an iterator instance.

Parameters:

iterator – [in]

CassIteratorType cass_iterator_type(CassIterator *iterator)¶

Gets the type of the specified iterator.

Parameters:

iterator – [in]

Returns:

The type of the iterator.

cass_bool_t cass_iterator_next(CassIterator *iterator)¶

Advance the iterator to the next row, column or collection item.

Parameters:

iterator – [in]

Returns:

false if no more rows, columns or items, otherwise true

const CassRow *cass_iterator_get_row(const CassIterator *iterator)¶

Gets the row at the result iterator’s current position.

Calling cass_iterator_next() will invalidate the previous row returned by this method.

Parameters:

iterator – [in]

Returns:

A row

const CassValue *cass_iterator_get_column(const CassIterator *iterator)¶

Gets the column value at the row iterator’s current position.

Calling cass_iterator_next() will invalidate the previous column returned by this method.

Parameters:

iterator – [in]

Returns:

A value

const CassValue *cass_iterator_get_value(const CassIterator *iterator)¶

Gets the value at a collection or tuple iterator’s current position.

Calling cass_iterator_next() will invalidate the previous value returned by this method.

Parameters:

iterator – [in]

Returns:

A value

const CassValue *cass_iterator_get_map_key(const CassIterator *iterator)¶

Gets the key at the map iterator’s current position.

Calling cass_iterator_next() will invalidate the previous value returned by this method.

Parameters:

iterator – [in]

Returns:

A value

const CassValue *cass_iterator_get_map_value(const CassIterator *iterator)¶

Gets the value at the map iterator’s current position.

Calling cass_iterator_next() will invalidate the previous value returned by this method.

Parameters:

iterator – [in]

Returns:

A value

CassError cass_iterator_get_user_type_field_name(const CassIterator *iterator, const char **name, size_t *name_length)¶

Gets the field name at the user type defined iterator’s current position.

Calling cass_iterator_next() will invalidate the previous name returned by this method.

Parameters:
  • iterator – [in]

  • name – [out]

  • name_length – [out]

Returns:

CASS_OK if successful, otherwise error occurred

const CassValue *cass_iterator_get_user_type_field_value(const CassIterator *iterator)¶

Gets the field value at the user type defined iterator’s current position.

Calling cass_iterator_next() will invalidate the previous value returned by this method.

Parameters:

iterator – [in]

Returns:

A value

const CassKeyspaceMeta *cass_iterator_get_keyspace_meta(const CassIterator *iterator)¶

Gets the keyspace metadata entry at the iterator’s current position.

Calling cass_iterator_next() will invalidate the previous value returned by this method.

Parameters:

iterator – [in]

Returns:

A keyspace metadata entry

const CassTableMeta *cass_iterator_get_table_meta(const CassIterator *iterator)¶

Gets the table metadata entry at the iterator’s current position.

Calling cass_iterator_next() will invalidate the previous value returned by this method.

Parameters:

iterator – [in]

Returns:

A table metadata entry

const CassMaterializedViewMeta *cass_iterator_get_materialized_view_meta(const CassIterator *iterator)¶

Gets the materialized view metadata entry at the iterator’s current position.

Calling cass_iterator_next() will invalidate the previous value returned by this method.

Parameters:

iterator – [in]

Returns:

A materialized view metadata entry

const CassDataType *cass_iterator_get_user_type(const CassIterator *iterator)¶

Gets the type metadata entry at the iterator’s current position.

Calling cass_iterator_next() will invalidate the previous value returned by this method.

Parameters:

iterator – [in]

Returns:

A type metadata entry

const CassFunctionMeta *cass_iterator_get_function_meta(const CassIterator *iterator)¶

Gets the function metadata entry at the iterator’s current position.

Calling cass_iterator_next() will invalidate the previous value returned by this method.

Warning: This function is not yet implemented.

Parameters:

iterator – [in]

Returns:

A function metadata entry

const CassAggregateMeta *cass_iterator_get_aggregate_meta(const CassIterator *iterator)¶

Gets the aggregate metadata entry at the iterator’s current position.

Calling cass_iterator_next() will invalidate the previous value returned by this method.

Warning: This function is not yet implemented.

Parameters:

iterator – [in]

Returns:

A aggregate metadata entry

const CassColumnMeta *cass_iterator_get_column_meta(const CassIterator *iterator)¶

Gets the column metadata entry at the iterator’s current position.

Calling cass_iterator_next() will invalidate the previous value returned by this method.

Parameters:

iterator – [in]

Returns:

A column metadata entry

const CassIndexMeta *cass_iterator_get_index_meta(const CassIterator *iterator)¶

Gets the index metadata entry at the iterator’s current position.

Calling cass_iterator_next() will invalidate the previous value returned by this method.

Warning: This function is not yet implemented.

Parameters:

iterator – [in]

Returns:

A index metadata entry

CassError cass_iterator_get_meta_field_name(const CassIterator *iterator, const char **name, size_t *name_length)¶

Gets the metadata field name at the iterator’s current position.

Calling cass_iterator_next() will invalidate the previous value returned by this method.

Warning: This function is not yet implemented.

Parameters:
  • iterator – [in]

  • name – [out]

  • name_length – [out]

Returns:

CASS_OK if successful, otherwise error occurred

const CassValue *cass_iterator_get_meta_field_value(const CassIterator *iterator)¶

Gets the metadata field value at the iterator’s current position.

Calling cass_iterator_next() will invalidate the previous value returned by this method.

Warning: This function is not yet implemented.

Parameters:

iterator – [in]

Returns:

A metadata field value

Was this page helpful?

PREVIOUS
CassInet
NEXT
CassKeyspaceMeta
  • Create an issue
  • Edit this page

On this page

  • CassIterator
    • CassIterator
      • CassIteratorType
      • cass_iterator_free()
      • cass_iterator_type()
      • cass_iterator_next()
      • cass_iterator_get_row()
      • cass_iterator_get_column()
      • cass_iterator_get_value()
      • cass_iterator_get_map_key()
      • cass_iterator_get_map_value()
      • cass_iterator_get_user_type_field_name()
      • cass_iterator_get_user_type_field_value()
      • cass_iterator_get_keyspace_meta()
      • cass_iterator_get_table_meta()
      • cass_iterator_get_materialized_view_meta()
      • cass_iterator_get_user_type()
      • cass_iterator_get_function_meta()
      • cass_iterator_get_aggregate_meta()
      • cass_iterator_get_column_meta()
      • cass_iterator_get_index_meta()
      • cass_iterator_get_meta_field_name()
      • cass_iterator_get_meta_field_value()
ScyllaDB CPP RS Driver
  • master
    • master
    • v1.0.0
  • ScyllaDB CPP RS Driver
  • API Documentation
    • BasicTypes
    • CassConsistency
    • CassError
    • CassValueType
    • CustomAllocator
    • Logging
    • Miscellaneous
    • CassAggregateMeta
    • CassAuthenticator
    • CassAuthenticatorCallbacks
    • CassBatch
    • CassCluster
    • CassCollection
    • CassColumnMeta
    • CassCustomPayload
    • CassDataType
    • CassErrorResult
    • CassExecProfile
    • CassFunctionMeta
    • CassFuture
    • CassIndexMeta
    • CassInet
    • CassIterator
    • CassKeyspaceMeta
    • CassMaterializedViewMeta
    • CassMetrics
    • CassNode
    • CassPrepared
    • CassResult
    • CassRetryPolicy
    • CassRow
    • CassSchemaMeta
    • CassSession
    • CassSpeculativeExecutionMetrics
    • CassSsl
    • CassStatement
    • CassTableMeta
    • CassTimestampGen
    • CassTuple
    • CassUserType
    • CassUuid
    • CassUuidGen
    • CassValue
    • CassVersion
  • Getting Started
  • Architecture Overview
  • Installation
  • Building
  • Testing
  • Using the Driver
    • Batches
    • Binding Parameters
    • Client-side timestamps
    • Consistency
    • Data Types
      • The date and time Types
      • Tuples
      • User-Defined Types (UDTs)
      • UUIDs
    • Futures
    • Handling Results
    • Keyspaces
    • Prepared Statements
    • Schema Metadata
  • Configuration
    • Load balancing
    • Retry policies
    • Speculative Execution
    • Connection
    • Execution Profiles
    • Performance Tips
    • Client Configuration
  • Security
    • Authentication
    • TLS
  • Observability
    • Logging
    • Tracing
    • Metrics
Docs Tutorials University Contact Us About Us
© 2026, ScyllaDB. All rights reserved. | Terms of Service | Privacy Policy | ScyllaDB, and ScyllaDB Cloud, are registered trademarks of ScyllaDB, Inc.
Last updated on 17 Mar 2026.
Powered by Sphinx 9.1.0 & ScyllaDB Theme 1.9.1
Ask AI