Was this page helpful?
Caution
You're viewing documentation for an unstable version of ScyllaDB CPP RS Driver. Switch to the latest stable version.
CassNode¶
-
struct CassNode¶
An object that represents a cluster node.
Caution
You're viewing documentation for an unstable version of ScyllaDB CPP RS Driver. Switch to the latest stable version.
An object that represents a cluster node.
Was this page helpful?