ScyllaDB University Live | Free Virtual Training Event
Learn more
ScyllaDB Documentation Logo Documentation
  • Deployments
    • Cloud
    • Server
  • Tools
    • ScyllaDB Manager
    • ScyllaDB Monitoring Stack
    • ScyllaDB Operator
  • Drivers
    • CQL Drivers
    • DynamoDB Drivers
    • Supported Driver Versions
  • Resources
    • ScyllaDB University
    • Community Forum
    • Tutorials
Install
Ask AI
ScyllaDB Docs ScyllaDB CPP RS Driver API Documentation CassRow

Caution

You're viewing documentation for an unstable version of ScyllaDB CPP RS Driver. Switch to the latest stable version.

CassRow¶

struct CassRow¶

A collection of column values.

Public Functions

CassIterator *cass_iterator_from_row(const CassRow *row)¶

Creates a new iterator for the specified row. This can be used to iterate over columns in a row.

See also

cass_iterator_free()

Parameters:

row – [in]

Returns:

A new iterator that must be freed.

const CassValue *cass_row_get_column(const CassRow *row, size_t index)¶

Get the column value at index for the specified row.

Parameters:
  • row – [in]

  • index – [in]

Returns:

The column value at the specified index. NULL is returned if the index is out of bounds.

const CassValue *cass_row_get_column_by_name(const CassRow *row, const char *name)¶

Get the column value by name for the specified row.

Parameters:
  • row – [in]

  • name – [in]

Returns:

The column value for the specified name. NULL is returned if the column does not exist.

const CassValue *cass_row_get_column_by_name_n(const CassRow *row, const char *name, size_t name_length)¶

Same as cass_row_get_column_by_name(), but with lengths for string parameters.

See also

cass_row_get_column_by_name()

Parameters:
  • row – [in]

  • name – [in]

  • name_length – [in]

Returns:

same as cass_row_get_column_by_name()

Was this page helpful?

PREVIOUS
CassRetryPolicy
NEXT
CassSchemaMeta
  • Create an issue
  • Edit this page

On this page

  • CassRow
    • CassRow
      • cass_iterator_from_row()
      • cass_row_get_column()
      • cass_row_get_column_by_name()
      • cass_row_get_column_by_name_n()
ScyllaDB CPP RS Driver
  • master
    • master
    • v1.0.0
  • ScyllaDB CPP RS Driver
  • API Documentation
    • BasicTypes
    • CassConsistency
    • CassError
    • CassValueType
    • CustomAllocator
    • Logging
    • Miscellaneous
    • CassAggregateMeta
    • CassAuthenticator
    • CassAuthenticatorCallbacks
    • CassBatch
    • CassCluster
    • CassCollection
    • CassColumnMeta
    • CassCustomPayload
    • CassDataType
    • CassErrorResult
    • CassExecProfile
    • CassFunctionMeta
    • CassFuture
    • CassIndexMeta
    • CassInet
    • CassIterator
    • CassKeyspaceMeta
    • CassMaterializedViewMeta
    • CassMetrics
    • CassNode
    • CassPrepared
    • CassResult
    • CassRetryPolicy
    • CassRow
    • CassSchemaMeta
    • CassSession
    • CassSpeculativeExecutionMetrics
    • CassSsl
    • CassStatement
    • CassTableMeta
    • CassTimestampGen
    • CassTuple
    • CassUserType
    • CassUuid
    • CassUuidGen
    • CassValue
    • CassVersion
  • Getting Started
  • Architecture Overview
  • Installation
  • Building
  • Testing
  • Using the Driver
    • Batches
    • Binding Parameters
    • Client-side timestamps
    • Consistency
    • Data Types
      • The date and time Types
      • Tuples
      • User-Defined Types (UDTs)
      • UUIDs
    • Futures
    • Handling Results
    • Keyspaces
    • Prepared Statements
    • Schema Metadata
  • Configuration
    • Load balancing
    • Retry policies
    • Speculative Execution
    • Connection
    • Execution Profiles
    • Performance Tips
    • Client Configuration
  • Security
    • Authentication
    • TLS
  • Observability
    • Logging
    • Tracing
    • Metrics
Docs Tutorials University Contact Us About Us
© 2026, ScyllaDB. All rights reserved. | Terms of Service | Privacy Policy | ScyllaDB, and ScyllaDB Cloud, are registered trademarks of ScyllaDB, Inc.
Last updated on 17 Mar 2026.
Powered by Sphinx 9.1.0 & ScyllaDB Theme 1.9.1
Ask AI