ScyllaDB University Live | Free Virtual Training Event
Learn more
ScyllaDB Documentation Logo Documentation
  • Deployments
    • Cloud
    • Server
  • Tools
    • ScyllaDB Manager
    • ScyllaDB Monitoring Stack
    • ScyllaDB Operator
  • Drivers
    • CQL Drivers
    • DynamoDB Drivers
    • Supported Driver Versions
  • Resources
    • ScyllaDB University
    • Community Forum
    • Tutorials
Install
Ask AI
ScyllaDB Docs ScyllaDB CPP RS Driver API Documentation CassUuidGen

Caution

You're viewing documentation for an unstable version of ScyllaDB CPP RS Driver. Switch to the latest stable version.

CassUuidGen¶

struct CassUuidGen¶

A UUID generator object.

Instances of the UUID generator object are thread-safe to generate UUIDs.

Public Functions

CassUuidGen *cass_uuid_gen_new()¶

Creates a new UUID generator.

Note: This object is thread-safe. It is best practice to create and reuse a single object per application.

Note: If unique node information (IP address) is unable to be determined then random node information will be generated.

See also

cass_uuid_gen_free()

See also

cass_uuid_gen_new_with_node()

Returns:

Returns a UUID generator that must be freed.

CassUuidGen *cass_uuid_gen_new_with_node(cass_uint64_t node)¶

Creates a new UUID generator with custom node information.

Note: This object is thread-safe. It is best practice to create and reuse a single object per application.

See also

cass_uuid_gen_free()

Returns:

Returns a UUID generator that must be freed.

void cass_uuid_gen_free(CassUuidGen *uuid_gen)¶

Frees a UUID generator instance.

Parameters:

uuid_gen – [in]

void cass_uuid_gen_time(CassUuidGen *uuid_gen, CassUuid *output)¶

Generates a V1 (time) UUID.

Note: This method is thread-safe

Parameters:
  • uuid_gen – [in]

  • output – [out] A V1 UUID for the current time.

void cass_uuid_gen_random(CassUuidGen *uuid_gen, CassUuid *output)¶

Generates a new V4 (random) UUID

Note:: This method is thread-safe

Parameters:
  • uuid_gen – [in]

  • output – A randomly generated V4 UUID.

void cass_uuid_gen_from_time(CassUuidGen *uuid_gen, cass_uint64_t timestamp, CassUuid *output)¶

Generates a V1 (time) UUID for the specified time.

Note:: This method is thread-safe

Parameters:
  • uuid_gen – [in]

  • timestamp – [in]

  • output – [out] A V1 UUID for the specified time.

Was this page helpful?

PREVIOUS
CassUuid
NEXT
CassValue
  • Create an issue
  • Edit this page

On this page

  • CassUuidGen
    • CassUuidGen
      • cass_uuid_gen_new()
      • cass_uuid_gen_new_with_node()
      • cass_uuid_gen_free()
      • cass_uuid_gen_time()
      • cass_uuid_gen_random()
      • cass_uuid_gen_from_time()
ScyllaDB CPP RS Driver
  • master
    • master
    • v1.0.0
  • ScyllaDB CPP RS Driver
  • API Documentation
    • BasicTypes
    • CassConsistency
    • CassError
    • CassValueType
    • CustomAllocator
    • Logging
    • Miscellaneous
    • CassAggregateMeta
    • CassAuthenticator
    • CassAuthenticatorCallbacks
    • CassBatch
    • CassCluster
    • CassCollection
    • CassColumnMeta
    • CassCustomPayload
    • CassDataType
    • CassErrorResult
    • CassExecProfile
    • CassFunctionMeta
    • CassFuture
    • CassIndexMeta
    • CassInet
    • CassIterator
    • CassKeyspaceMeta
    • CassMaterializedViewMeta
    • CassMetrics
    • CassNode
    • CassPrepared
    • CassResult
    • CassRetryPolicy
    • CassRow
    • CassSchemaMeta
    • CassSession
    • CassSpeculativeExecutionMetrics
    • CassSsl
    • CassStatement
    • CassTableMeta
    • CassTimestampGen
    • CassTuple
    • CassUserType
    • CassUuid
    • CassUuidGen
    • CassValue
    • CassVersion
  • Getting Started
  • Architecture Overview
  • Installation
  • Building
  • Testing
  • Using the Driver
    • Batches
    • Binding Parameters
    • Client-side timestamps
    • Consistency
    • Data Types
      • The date and time Types
      • Tuples
      • User-Defined Types (UDTs)
      • UUIDs
    • Futures
    • Handling Results
    • Keyspaces
    • Prepared Statements
    • Schema Metadata
  • Configuration
    • Load balancing
    • Retry policies
    • Speculative Execution
    • Connection
    • Execution Profiles
    • Performance Tips
    • Client Configuration
  • Security
    • Authentication
    • TLS
  • Observability
    • Logging
    • Tracing
    • Metrics
Docs Tutorials University Contact Us About Us
© 2026, ScyllaDB. All rights reserved. | Terms of Service | Privacy Policy | ScyllaDB, and ScyllaDB Cloud, are registered trademarks of ScyllaDB, Inc.
Last updated on 17 Mar 2026.
Powered by Sphinx 9.1.0 & ScyllaDB Theme 1.9.1
Ask AI