ScyllaDB University Live | Free Virtual Training Event
Learn more
ScyllaDB Documentation Logo Documentation
  • Deployments
    • Cloud
    • Server
  • Tools
    • ScyllaDB Manager
    • ScyllaDB Monitoring Stack
    • ScyllaDB Operator
  • Drivers
    • CQL Drivers
    • DynamoDB Drivers
    • Supported Driver Versions
  • Resources
    • ScyllaDB University
    • Community Forum
    • Tutorials
Install
Ask AI
ScyllaDB Docs ScyllaDB CPP RS Driver API Documentation CassValue

Caution

You're viewing documentation for an unstable version of ScyllaDB CPP RS Driver. Switch to the latest stable version.

CassValue¶

struct CassValue¶

A single primitive value or a collection of values.

Public Functions

CassIterator *cass_iterator_from_collection(const CassValue *value)¶

Creates a new iterator for the specified collection. This can be used to iterate over values in a collection.

See also

cass_iterator_free()

Parameters:

value – [in]

Returns:

A new iterator that must be freed. NULL returned if the value is not a collection.

CassIterator *cass_iterator_from_map(const CassValue *value)¶

Creates a new iterator for the specified map. This can be used to iterate over key/value pairs in a map.

See also

cass_iterator_free()

Parameters:

value – [in]

Returns:

A new iterator that must be freed. NULL returned if the value is not a map.

CassIterator *cass_iterator_from_tuple(const CassValue *value)¶

Creates a new iterator for the specified tuple. This can be used to iterate over values in a tuple.

See also

cass_iterator_free()

Parameters:

value – [in]

Returns:

A new iterator that must be freed. NULL returned if the value is not a tuple.

CassIterator *cass_iterator_fields_from_user_type(const CassValue *value)¶

Creates a new iterator for the specified user defined type. This can be used to iterate over fields in a user defined type.

See also

cass_iterator_free()

Parameters:

value – [in]

Returns:

A new iterator that must be freed. NULL returned if the value is not a user defined type.

const CassDataType *cass_value_data_type(const CassValue *value)¶

Gets the data type of a value.

Parameters:

value – [in]

Returns:

Returns a reference to the data type of the value. Do not free this reference as it is bound to the lifetime of the value.

CassError cass_value_get_int8(const CassValue *value, cass_int8_t *output)¶

Gets an int8 for the specified value.

Parameters:
  • value – [in]

  • output – [out]

Returns:

CASS_OK if successful, otherwise error occurred

CassError cass_value_get_int16(const CassValue *value, cass_int16_t *output)¶

Gets an int16 for the specified value.

Parameters:
  • value – [in]

  • output – [out]

Returns:

CASS_OK if successful, otherwise error occurred

CassError cass_value_get_int32(const CassValue *value, cass_int32_t *output)¶

Gets an int32 for the specified value.

Parameters:
  • value – [in]

  • output – [out]

Returns:

CASS_OK if successful, otherwise error occurred

CassError cass_value_get_uint32(const CassValue *value, cass_uint32_t *output)¶

Gets an uint32 for the specified value.

Parameters:
  • value – [in]

  • output – [out]

Returns:

CASS_OK if successful, otherwise error occurred

CassError cass_value_get_int64(const CassValue *value, cass_int64_t *output)¶

Gets an int64 for the specified value.

Parameters:
  • value – [in]

  • output – [out]

Returns:

CASS_OK if successful, otherwise error occurred

CassError cass_value_get_float(const CassValue *value, cass_float_t *output)¶

Gets a float for the specified value.

Parameters:
  • value – [in]

  • output – [out]

Returns:

CASS_OK if successful, otherwise error occurred

CassError cass_value_get_double(const CassValue *value, cass_double_t *output)¶

Gets a double for the specified value.

Parameters:
  • value – [in]

  • output – [out]

Returns:

CASS_OK if successful, otherwise error occurred

CassError cass_value_get_bool(const CassValue *value, cass_bool_t *output)¶

Gets a bool for the specified value.

Parameters:
  • value – [in]

  • output – [out]

Returns:

CASS_OK if successful, otherwise error occurred

CassError cass_value_get_uuid(const CassValue *value, CassUuid *output)¶

Gets a UUID for the specified value.

Parameters:
  • value – [in]

  • output – [out]

Returns:

CASS_OK if successful, otherwise error occurred

CassError cass_value_get_inet(const CassValue *value, CassInet *output)¶

Gets an INET for the specified value.

Parameters:
  • value – [in]

  • output – [out]

Returns:

CASS_OK if successful, otherwise error occurred

CassError cass_value_get_string(const CassValue *value, const char **output, size_t *output_size)¶

Gets a string for the specified value.

Parameters:
  • value – [in]

  • output – [out]

  • output_size – [out]

Returns:

CASS_OK if successful, otherwise error occurred

CassError cass_value_get_bytes(const CassValue *value, const cass_byte_t **output, size_t *output_size)¶

Gets the bytes of the specified value.

Parameters:
  • value – [in]

  • output – [out]

  • output_size – [out]

Returns:

CASS_OK if successful, otherwise error occurred

CassError cass_value_get_decimal(const CassValue *value, const cass_byte_t **varint, size_t *varint_size, cass_int32_t *scale)¶

Gets a decimal for the specified value.

Parameters:
  • value – [in]

  • varint – [out]

  • varint_size – [out]

  • scale – [out]

Returns:

CASS_OK if successful, otherwise error occurred

CassError cass_value_get_duration(const CassValue *value, cass_int32_t *months, cass_int32_t *days, cass_int64_t *nanos)¶

Gets a duration for the specified value.

Requires Apache Cassandra: 3.10+

Parameters:
  • value – [in]

  • months – [out]

  • days – [out]

  • nanos – [out]

Returns:

CASS_OK if successful, otherwise error occurred

CassValueType cass_value_type(const CassValue *value)¶

Gets the type of the specified value.

Parameters:

value – [in]

Returns:

The type of the specified value.

cass_bool_t cass_value_is_null(const CassValue *value)¶

Returns true if a specified value is null.

Parameters:

value – [in]

Returns:

true if the value is null, otherwise false.

cass_bool_t cass_value_is_collection(const CassValue *value)¶

Returns true if a specified value is a collection.

Parameters:

value – [in]

Returns:

true if the value is a collection, otherwise false.

cass_bool_t cass_value_is_duration(const CassValue *value)¶

Returns true if a specified value is a duration.

Parameters:

value – [in]

Returns:

true if the value is a duration, otherwise false.

size_t cass_value_item_count(const CassValue *collection)¶

Get the number of items in a collection. Works for all collection types.

Parameters:

collection – [in]

Returns:

Count of items in a collection. 0 if not a collection.

CassValueType cass_value_primary_sub_type(const CassValue *collection)¶

Get the primary sub-type for a collection. This returns the sub-type for a list or set and the key type for a map.

Parameters:

collection – [in]

Returns:

The type of the primary sub-type. CASS_VALUE_TYPE_UNKNOWN returned if not a collection.

CassValueType cass_value_secondary_sub_type(const CassValue *collection)¶

Get the secondary sub-type for a collection. This returns the value type for a map.

Parameters:

collection – [in]

Returns:

The type of the primary sub-type. CASS_VALUE_TYPE_UNKNOWN returned if not a collection or not a map.

Was this page helpful?

PREVIOUS
CassUuidGen
NEXT
CassVersion
  • Create an issue
  • Edit this page

On this page

  • CassValue
    • CassValue
      • cass_iterator_from_collection()
      • cass_iterator_from_map()
      • cass_iterator_from_tuple()
      • cass_iterator_fields_from_user_type()
      • cass_value_data_type()
      • cass_value_get_int8()
      • cass_value_get_int16()
      • cass_value_get_int32()
      • cass_value_get_uint32()
      • cass_value_get_int64()
      • cass_value_get_float()
      • cass_value_get_double()
      • cass_value_get_bool()
      • cass_value_get_uuid()
      • cass_value_get_inet()
      • cass_value_get_string()
      • cass_value_get_bytes()
      • cass_value_get_decimal()
      • cass_value_get_duration()
      • cass_value_type()
      • cass_value_is_null()
      • cass_value_is_collection()
      • cass_value_is_duration()
      • cass_value_item_count()
      • cass_value_primary_sub_type()
      • cass_value_secondary_sub_type()
ScyllaDB CPP RS Driver
  • master
    • master
    • v1.0.0
  • ScyllaDB CPP RS Driver
  • API Documentation
    • BasicTypes
    • CassConsistency
    • CassError
    • CassValueType
    • CustomAllocator
    • Logging
    • Miscellaneous
    • CassAggregateMeta
    • CassAuthenticator
    • CassAuthenticatorCallbacks
    • CassBatch
    • CassCluster
    • CassCollection
    • CassColumnMeta
    • CassCustomPayload
    • CassDataType
    • CassErrorResult
    • CassExecProfile
    • CassFunctionMeta
    • CassFuture
    • CassIndexMeta
    • CassInet
    • CassIterator
    • CassKeyspaceMeta
    • CassMaterializedViewMeta
    • CassMetrics
    • CassNode
    • CassPrepared
    • CassResult
    • CassRetryPolicy
    • CassRow
    • CassSchemaMeta
    • CassSession
    • CassSpeculativeExecutionMetrics
    • CassSsl
    • CassStatement
    • CassTableMeta
    • CassTimestampGen
    • CassTuple
    • CassUserType
    • CassUuid
    • CassUuidGen
    • CassValue
    • CassVersion
  • Getting Started
  • Architecture Overview
  • Installation
  • Building
  • Testing
  • Using the Driver
    • Batches
    • Binding Parameters
    • Client-side timestamps
    • Consistency
    • Data Types
      • The date and time Types
      • Tuples
      • User-Defined Types (UDTs)
      • UUIDs
    • Futures
    • Handling Results
    • Keyspaces
    • Prepared Statements
    • Schema Metadata
  • Configuration
    • Load balancing
    • Retry policies
    • Speculative Execution
    • Connection
    • Execution Profiles
    • Performance Tips
    • Client Configuration
  • Security
    • Authentication
    • TLS
  • Observability
    • Logging
    • Tracing
    • Metrics
Docs Tutorials University Contact Us About Us
© 2026, ScyllaDB. All rights reserved. | Terms of Service | Privacy Policy | ScyllaDB, and ScyllaDB Cloud, are registered trademarks of ScyllaDB, Inc.
Last updated on 17 Mar 2026.
Powered by Sphinx 9.1.0 & ScyllaDB Theme 1.9.1
Ask AI